(* ::Package:: *)

BeginPackage["StatisticalPackage`"]

ProbAlpha::usage = 
    "ProbAlpha[N, n, f] returns the probability that a sample of size \n, from a population of N elements of which a fraction f is 
defective, will contain no defective elements"; 

SizeSample::usage = 
    "SizeSample[N, alfa, f] returns the sample size n required to have a confidence level 1-alpha that the population N contains a
fraction of defective elements lower or equal to f"; 

Begin["`Private`"]


ProbAlpha[N_Integer, n_, f_] := FunctionExpand[Binomial[(1 - f)*N, n]/Binomial[N, n]]; 

SizeSample[N_Integer, alpha_, f_] := 
       Ceiling[n /. FindRoot[ProbAlpha[N, n, f] == alpha, {n, 20}]] /;N >= 100; 

SizeSample[N_Integer, alpha_, f_] := 
  "N must be at least 100" /; N < 100;

End[]

EndPackage[]
